"""django-crucrudile provides URL routing classes, which allows you to
define your URL routing structure using Router and Route classes, and
then to automatically generate an URL pattern structure.

Documentation
-------------

Documentation is built using Sphinx (using static reStructuredText
files stored in ``docs`` and Sphinx-formatted docstrings in modules,
classes and functions).

Use the following command to build the documentation in ``docs/_build``::

  sphinx-build -E -c docs -b html -a docs docs/_build

The documentation can also be viewed online, at
https://django-crucrudile.readthedocs.org/en/master/.

Versionning
-----------

Starting from version ``0.9.5``, this package uses semantic version
(http://semver.org).

"""
__title__ = 'django-crucrudile'
__description__ = 'Django URL routing classes',

__version__ = '0.9.5'

__author__ = 'Hugo Geoffroy'
__author_email__ = 'hugo@pstch.net'

__license__ = 'GNU General Public License V3.0'
__copyright__ = 'Copyright 2013-2014 Hugo Geoffroy'
__url__ = 'https://github.com/pstch/django-crucrudile'
